/*
 * Copyright 2002-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.integration.transformer;

import org.springframework.messaging.Message;
import org.springframework.messaging.MessagingException;

/**
 * Base Exception type for Message transformation errors.
 *
 * @author Mark Fisher
 * @author Artem Bilan
 */
@SuppressWarnings("serial")
public class MessageTransformationException extends MessagingException {

	public MessageTransformationException(Message<?> message, String description, Throwable cause) {
		super(message, description, cause);
	}

	public MessageTransformationException(Message<?> message, String description) {
		super(message, description);
	}

	/**
	 * @param message the failed {@link Message}
	 * @param cause the cause {@link Throwable}
	 * @deprecated since 4.2 in favor of {@link #MessageTransformationException(Message, String, Throwable)}.
	 */
	@Deprecated
	public MessageTransformationException(Message<?> message, Throwable cause) {
		this(message, cause.getMessage(), cause);
	}

	public MessageTransformationException(String description, Throwable cause) {
		super(description, cause);
	}

	public MessageTransformationException(String description) {
		super(description);
	}

}
